==================
Computational grid
==================

SWAN computational grid commands
 
.. autosummary::
   :nosignatures:
   :toctree: _generated/

   rompy_swan.components.cgrid.REGULAR
   rompy_swan.components.cgrid.CURVILINEAR
   rompy_swan.components.cgrid.UNSTRUCTURED

